﻿© 2001 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek TDS2xx: Main Trigger IEEE/: 1.00
DATE:                  2001-06-26
AUTHOR:                MSD
REVISION:              $Revision: 1.00 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       167
=============================================================================
#@
#@ Procedure ID No: 001157M002
#@
#@ Models covered:  210, 220,  224
#@
#@ Source:     Tektronix TDS 200 Series
#@             Service Manual
#@             Digital Real-Time Oscilloscope
#@             071-0492-02
#@
#@
#@ Source Author:   N/K
#@
#@ Compatibility:   MET/CAL 6.10 or later
#@
#@ Subprocedures:
#@              Sub Wait for Operation Complete (OPC) IEEE/: 1.00
#@              Sub Tek TDS2xx: Main Trigger IEEE/: 1.00
#@
#@ Required Files:
#@
#@
#@ Additional equipment Required:
#@
#@               Two BNC (f/m) Right Angle Adaptors (Pomona 90191 Model 3534)
#@
#@ The Procedure was tested using:
#@
#@                  Model No  TEKTRONIX TDS 224
#@                  Serial No BO25022
#@                  Options   N/A
#@                  Firmware Ver FV:v1.06
#@                  Module Firmware Ver TDS2CM:CMV:v1.04
#@
#@
#@ Procedure history:
#@      21-06-01: New Procedure
#@
#@ The procedure is intended for use with Met/Cal(r) calibration software,
#@ and the terms and conditions set forth in your METCAL license apply to
#@ this procedure.
#@
#@ Due to our policy of continuously up dating our products, this procedure
#@ may contain minor differences in specification to those found in the manual
#@ or other documentation. While every effort has been made to ensure that
#@ this procedure is accurate, Fluke cannot be held responsible for the
#@ consequences of error or omissions found within this procedure.
#@
#@ The copyright in this procedure is owned by Fluke Precision Measurement
#@ Limited.
#@
#@   M[10] =  THIS VARIABLE IS SOMETIMES USED IN THE MAIN PROCEDURE
#@            as a Watchdog timer also.
#@   M[11] =  Holds value of MEM.
#@   M[12] =  Holds value of MEM1.
#@   MEM2 =   Passes commands to the status check subprocedure.
#@            This is used with the READING Flag.
#@            The benefit of using this technique is the ability to reduce
#@            the amount of dedicated programs.
#@   M[1] =   Used in the Trigger Section of the procedure to store
#@            temporary values of MEM.
#@            This section is part of a feedback loop which
#@            is used to adjust the 9500 to the proper amplitude.
#@   M[2] =   Used in the Trigger Section of the procedure to calculate
#@            how much the 9500 will be adjusted in the feedback loop.
#@            This register is also used in the bandwidth tests.
#@   M[3] =   Used in the main triggering section to help determine
#@            whether the scope is making a correct type of measurement.
#@            This register sets the starting trigger level also.
#@   M[4] =   Stores a value to be to be compared later.
#@   M[102] = Scope Bandwidth
#@
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Backup MEM and MEM1
  1.001  MATH         M[11] = MEM
  1.002  MATH         M[12] = MEM1


# ******************** MAIN TRIGGER ********************

  1.003  MATH         M[20] = 0

  1.004  LABEL        MAIN_TRIGGER

# Trigger Level we will start with
  1.005  IEEE         TRIGGER:MAIN SETLEVEL
  1.006  CALL         Sub Wait for Operation Complete (OPC) IEEE/: 1.00
  1.007  JMPL         RESTORE_MEM_AND_MEM1  M[89] <= 0
  1.008  MATH         M[1]  = 0
  1.009  MATH         M[10] = 0
  1.010  IEEE         TRIGGER:MAIN:LEVEL [M3]

  1.011  LABEL        TEST_MAIN_LEVEL

# Increment Master Watchdog counter
  1.012  MATH         M[1] = M[1] + 1

# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  1.013  JMPL         FAIL_MAIN_TRIGGER            M[1] >= 100

# Read the Trigger State
  1.014  IEEE         [D250]TRIGGER:STATE?[I$]
  1.015  JMPL         TRIG                 M[20] > 0

# If MAIN TRIGGER was called directly the response must TRIGgered.
  1.016  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
  1.017  JMPL         CHECK_MAIN_RESPONSE

  1.018  LABEL        TRIG
# If MAIN TRIGGER was called from DELAY TRIGGER
  1.019  MATH         MEM1 = FIND(MEM2, "TRIG", 1)

  1.020  LABEL        CHECK_MAIN_RESPONSE
  1.021  JMPL         ADJUST_MAIN_LEVEL            MEM1 < 1

# Increment the good trigger counter
  1.022  MATH         M[10] = M[10] + 1

# Jump out of the loop if the system records over 10 good triggers
  1.023  JMPL         END_MAIN_TRIGGER             M[10] > 10

# Go back to the trigger beginning
  1.024  JMPL         TEST_MAIN_LEVEL

  1.025  LABEL        ADJUST_MAIN_LEVEL

# Reset the good trigger counter
  1.026  MATH         M[10] = 0

# If we counted too high, start over
  1.027  JMPL         INCREMENT_MAIN_LEVEL         MEM < ABS(M[3])
  1.028  MATH         MEM = M[3]

  1.029  LABEL        INCREMENT_MAIN_LEVEL
  1.030  MATH         MEM = MEM + M[4]
  1.031  IEEE         TRIGGER:MAIN:LEVEL [MEM]
  1.032  HEAD         MAIN TRIGGER LEVEL: [MEM]V
  1.033  JMPL         TEST_MAIN_LEVEL

  1.034  LABEL        FAIL_MAIN_TRIGGER

# Set a value for M[10] which will later be evaluated as a failure
  1.035  MATH         M[10] = 0

  1.036  LABEL        END_MAIN_TRIGGER
  1.037  JMPL         RESTORE_MEM_AND_MEM1

  1.038  EVAL   dummy

# ************************* END OF PROCEDURES ****************************

  2.001  LABEL        RESTORE_MEM_AND_MEM1
  2.002  MATH         MEM = M[11]
  2.003  MATH         MEM1 = M[12]
  2.004  END
